@@ -11,7 +11,6 @@ from metasdk.exceptions import RetryHttpRequestError, EndOfTriesError, Unexpecte
 
 
 class ApiProxyService:
-
     MAX_PAGES = 100000
 
     def __init__(self, app):
@@ -24,14 +23,15 @@ class ApiProxyService:
         self.__data_get_flatten_cache = {}
 
     def __api_proxy_call(self, engine, payload, method, analyze_json_error_param, retry_request_substr_variants,
-                         stream=False, raise_business_errors=False):
+                         stream: bool = False, raise_business_errors: bool = False, log: bool = False):
         """
         :param engine: Система
         :param payload: Данные для запроса
         :param method: string Может содержать native_call | tsv | json_newline
         :param analyze_json_error_param: Нужно ли производить анализ параметра error в ответе прокси
         :param retry_request_substr_variants: Список подстрок, при наличии которых в ответе будет происходить перезапрос
-        :param stream:
+        :param stream: стримиговый запрос, можно будет итерироваться по строкам ответа, не загружая весь ответ в память
+        :param log: логировать параметры запроса
         :return:
         """
         log_ctx = {
@@ -39,7 +39,8 @@ class ApiProxyService:
             "method": payload.get('method'),
             "method_params": payload.get('method_params')
         }
-        self.__app.log.info("Call api proxy", log_ctx)
+        if log:
+            self.__app.log.info("Call api proxy", log_ctx)
         body = {
             "engine": engine,
             "payload": payload
@@ -72,7 +73,7 @@ class ApiProxyService:
         raise EndOfTriesError("Api of api proxy tries request")
 
     def call_proxy_with_paging(self, engine, payload, method, analyze_json_error_param, retry_request_substr_variants,
-                               max_pages=MAX_PAGES, raise_business_errors=False):
+                               max_pages: int = MAX_PAGES, raise_business_errors: bool = False, log: bool = False):
         """
         Постраничный запрос
         :param engine: Система
@@ -81,15 +82,18 @@ class ApiProxyService:
         :param analyze_json_error_param: Нужно ли производить анализ параметра error в ответе прокси
         :param retry_request_substr_variants: Список подстрок, при наличии которых в ответе будет происходить перезапрос
         :param max_pages: Максимальное количество страниц в запросе
-        :return: объект генератор
+        :param stream: стримиговый запрос, можно будет итерироваться по строкам ответа, не загружая весь ответ в память
         :param raise_business_errors: Преобразовывать ApiProxyError в конкретную BusinessError
+        :param log: логировать параметры запроса
+        :return: объект генератор
         """
         copy_payload = copy.deepcopy(payload)
 
         idx = 0
         for idx in range(max_pages):
             resp = self.__api_proxy_call(engine, copy_payload, method, analyze_json_error_param,
-                                         retry_request_substr_variants, raise_business_errors=raise_business_errors)
+                                         retry_request_substr_variants, raise_business_errors=raise_business_errors,
+                                         log=log)
             yield resp
 
             paging_resp = resp.json().get("paging")
@@ -101,7 +105,7 @@ class ApiProxyService:
             self.__app.log.warning("Достигнут максимальный предел страниц", {"max_pages": max_pages})
 
     def call_proxy(self, engine, payload, method, analyze_json_error_param, retry_request_substr_variants,
-                   stream=False, raise_business_errors=False):
+                   stream: bool = False, raise_business_errors: bool = False, log: bool = False):
         """
         :param engine: Система
         :param payload: Данные для запроса
@@ -109,7 +113,8 @@ class ApiProxyService:
         :param analyze_json_error_param: Нужно ли производить анализ параметра error в ответе прокси
         :param retry_request_substr_variants: Список подстрок, при наличии которых в ответе будет происходить перезапрос
         :param raise_business_errors: Преобразовывать ApiProxyError в конкретную BusinessError
-        :param stream:
+        :param stream: стримиговый запрос, можно будет итерироваться по строкам ответа, не загружая весь ответ в память
+        :param log: логировать параметры запроса
         :return:
         """
         return self.__api_proxy_call(engine, payload, method, analyze_json_error_param, retry_request_substr_variants,
@@ -140,7 +145,7 @@ class ApiProxyService:
             data_ = resp.json()
             error = data_.get("error")
             if error:
-                full_err_ = json.dumps(error)
+                full_err_ = json.dumps(error, ensure_ascii=False)
 
                 if error.get("type") == "RateLimitError":
                     raise RateLimitError(error.get("message"), waiting_time=error.get("waiting_time"))
